| atomize_help | R Documentation |
Get (and maybe process) a vector of all atoms contained in the full set of ... args.
atomize_help()
atomize(...)
glue_av(..., g = "")
paste_av(..., p = "", s = "")
sort_uv(...)
which_av(...)
sort_av(...)
unique_av(...)
atoms(...)
av(...)
a(...)
sv(...)
gv(..., g = "")
pv(..., p = "", s = "")
uv(...)
suv(...)
wv(...)
... |
Arguments to be atomized. Expected to atomize to a logical vector for |
g |
Character scalar glue for gluing. |
p |
Character scalar prefix. |
s |
Character scalar suffix. |
atomize(): Flattens ... args to an atomic vector of the constituent atomic elements of ... without any attributes. Returns an atomic vector.
glue_av(): Atomizes ... and glues the resulting atomic vector into an atomic scalar using g as the glue. Thinly wraps paste0(av(...), collapse = "g"). Returns a character scalar.
paste_av(): Atomizes ... and pastes a prefix and a suffix to the resulting values. Thinly wraps paste(p, av(...), s). Returns a character vector.
sort_uv(): Atomizes ... and sorts the unique values of the result. Thinly wraps sort(unique(av(...))). Returns a sorted unique atomic vector.
which_av(): Atomizes ... and integer indexes the TRUE values in the result. Thinly wraps which(av(...)). Returns a logical vector.
sort_av(): Atomizes ... and sorts the result. Thinly wraps sort(av(...)). Returns a sorted atomic vector.
unique_av(): Atomizes ... and returns the unique values of the result. Thinly wraps unique(av(...)). Returns a unique atomic vector.
atoms(): An alias for atomize.
av(): An alias for atomize.
a(): An alias for atomize.
sv(): An alias for sort_av.
gv(): An alias for glue_av.
pv(): An alias for paste_av.
uv(): An alias for unique_av.
suv(): An alias for sort_uv.
wv(): An alias for which_av.
x <- list("a", "b", "c")
y <- data.frame(1:3)
x
y
a(x)
av(y)
atoms(x, y)
atomize(x, "d", y, 4)
glue_av(letters, LETTERS, g = "-")
paste_av(letters, p = "\u2022 ", s = ".")
sort_av(letters, LETTERS, 0:9)
sort_uv(letters, LETTERS, 0:9)
unique_av(letters, "d", 0:9, 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.