| insert_help | R Documentation |
Manipulate positions, rows, and columns
insert_help()
insert_elts_before(x, new.elts, elt)
insert_cols_before(x, new.cols, col)
insert_rows_before(x, new.rows, row)
insert_elt_after(x, new.elts, elt)
insert_col_after(x, new.cols, col)
insert_after_row(x, new.rows, row)
x |
For |
new.elts |
An atomic vector compatible with |
elt |
A whole number scalar indexing a position of |
new.cols |
A matrix or data.frame compatible witht |
col |
A whole number scalar indexing a column of |
new.rows |
A matrix or data.frame compatible with |
row |
A whole number scalar indexing a row of |
elt < 0, col < 0, and row < 0 index from the last position, row, or column rather than the first.
An object of the same class as x with increased dimension.
insert_elts_before(): Insert new.elts into x before the elt-th positions of x.
insert_cols_before(): Insert new.cols into x before the col-th column of x.
insert_rows_before(): Insert new.rows into x before the row-th row of x.
insert_elt_after(): Insert new.elts into x after the elt-the position of x.
insert_col_after(): Insert new.cols into x after the col-th column of x.
insert_after_row(): Insert new.rows into x after the row-th row of x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.